Book Analytics Dashboard 
=======================

Documentation on how the Dashboard works and information on the data sources used.

.. toctree::
    :maxdepth: 2

    bad_project/overview/index

.. toctree::
    :maxdepth: 2

    bad_project/help/index


Book Usage Data Workflows
=======================

Documentation about the code/files hosted in the Book Usage Data Worfklows Github repository. This includes (technical) documentation on the telescope/analytical workflows that are a part of this repository, license info & contributing guidelines and auto-generated API reference documentation.

.. toctree::
    :maxdepth: 2

    oaebu_workflows/index